==> sfa-rpc-0.0.35-sources.jar: com/biz/sfa/vo/resp/media/AllMarketingSearchListRpcRespVo.java <==
package com.biz.sfa.vo.resp.media;

import com.biz.sfa.enums.ActivityStyleEnum;
import com.biz.sfa.enums.CostTypeEnum;
import com.biz.sfa.enums.MediaCategoriesEnum;
import com.biz.sfa.enums.SubdivisionEnum;

import java.io.Serializable;
import java.math.BigDecimal;
import java.sql.Timestamp;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Created by Administrator on 2017/7/17.
 */
public class AllMarketingSearchListRpcRespVo implements Serializable {

    private static final long serialVersionUID = -2910919988277359904L;

    /**
     * 媒体大类
     */
    private MediaCategoriesEnum mediaCategories;

    /**
     * 媒体大类名称
     */
    private String mediaCategoriesName;

    /**
     * 费用类型
     */
    private CostTypeEnum costType;

    /**
     * 费用类型名称
     */
    private String costTypeName;

    /**
     * 小类
     */
    private SubdivisionEnum subdivision;

    /**
     * 小类名称
     */
    private String subdivisionName;

    /**
     * 活动形式
     */
    private ActivityStyleEnum activityStyle;

    /**
     * 活动形式名称
     */
    private String activityStyleName;

    /**
     * 照片(外键关联)
     */
    private Set<Photo> photoes = new HashSet<Photo>();

    /**
     * 媒体库编码
     */
    private String mediaCode;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 播出开始时间(HH:mm:ss)
     */
    private Date playTimeStart;

    /**
     * 播出结束时间(HH:mm:ss)
     */
    private Date playTimeEnd;

    /**
     * 单位
     */
    private String unit;

    /**
     * 节目/活动/剧目名称
     */
    private String channelName;

    /**
     * 版面
     */
    private String pageLayout;

    /**
     * 位置
     */
    private String position;

    /**
     * 曝光量
     */
    private Integer exposureNumber;

    /**
     * 场馆
     */
    private String venue;

    /**
     * 站点/影院名称
     */
    private String theaterName;

    /**
     * 媒体数量
     */
    private Integer mediaNumber;

    /**
     * 尺寸（广告尺寸）
     */
    private String banner;

    /**
     * 亮化开始时间(HH:mm:ss)
     */
    private Long brightTimeStart;

    /**
     * 亮化结束时间(HH:mm:ss)
     */
    private Long brightTimeEnd;

    /**
     * （地理位置）省
     */
    private String province;

    /**
     * （地理位置）市
     */
    private String municipality;

    /**
     * （地理位置）县
     */
    private String county;

    /**
     * 地址详情
     */
    private String address;

    /**
     * 小区/道路名称
     */
    private String plot;

    /**
     * 道路名称
     */
    private String roadName;

    /**
     * 楼宇
     */
    private String building;

    /**
     * 竞品信息
     */
    private String competitionInformation;

    /**
     * 发布开始时间(yyyy-HH-dd)
     */
    private Timestamp releaseTimeStart;

    /**
     * 发布结束时间(yyyy-HH-dd)
     */
    private Timestamp releaseTimeEnd;

    /**
     * 项目金额
     */
    private BigDecimal itemMoney;

    /**
     * 年化媒体金额
     */
    private BigDecimal annualAmountOfMedia;

    /**
     * 频次
     */
    private Integer frequency;

    /**
     * 具体投放项目
     */
    private String specificDeliveryProject;

    /**
     * 线路
     */
    private String line;

    /**
     * 材质
     */
    private String material;

    /**
     * 车牌号
     */
    private String carNumber;

    /**
     * 车身尺寸
     */
    private String carBodySize;

    /**
     *始发站
     */
    private String startingPoint;

    /**
     *终点站
     */
    private String destination;

    /**
     * 高速名称
     */
    private String expresswayName;

    /**
     * 形状(横屏or竖屏)（0=横屏或者1=竖屏）
     */
    private Integer rotation;

    /**
     * 开机时间（HH:mm:ss）
     */
    private Long computerBootTime;

    /**
     * 关机时间（HH:mm:ss）
     */
    private Long computerShutdownTime;

    /**
     *网点名称
     */
    private String networtName;

    /**
     * 网点编码
     */
    private String networtCode;

    /**
     * 新增岗位编码
     */
    private String addJobCode;

    /**
     * 新增岗位人员编码
     */
    private String addJobPeopleCode;

    /**
     * 创建时间（yyyy-MM-dd HH:mm:ss)
     */
    private Timestamp createtime;

    /**
     * 最新修改时间（yyyy-MM-dd HH:mm:ss)
     */
    private Timestamp mtime;

    /**
     * 最新更新岗位编码
     */
    private String latestUpdatePostCode;

    /**
     * 最新更新岗位下人员
     */
    private String latestUpdatedPosts;

    /**
     * 是否停用
     */
    private Boolean stop;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 维度
     */
    private String latitude;

    /**
     * 大号/内容数量
     */
    private Integer tubaOrContentNum;

    /**
     * 备注
     */
    private String remarks;

    /**
     * 拓展字段
     */
    private List<String> developFields;

    public MediaCategoriesEnum getMediaCategories() {
        return mediaCategories;
    }

    public void setMediaCategories(MediaCategoriesEnum mediaCategories) {
        this.mediaCategories = mediaCategories;
    }

    public CostTypeEnum getCostType() {
        return costType;
    }

    public void setCostType(CostTypeEnum costType) {
        this.costType = costType;
    }

    public SubdivisionEnum getSubdivision() {
        return subdivision;
    }

    public void setSubdivision(SubdivisionEnum subdivision) {
        this.subdivision = subdivision;
    }

    public ActivityStyleEnum getActivityStyle() {
        return activityStyle;
    }

    public void setActivityStyle(ActivityStyleEnum activityStyle) {
        this.activityStyle = activityStyle;
    }

    public String getMediaName() {
        return mediaName;
    }

    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    public Date getPlayTimeStart() {
        return playTimeStart;
    }

    public void setPlayTimeStart(Date playTimeStart) {
        this.playTimeStart = playTimeStart;
    }

    public Date getPlayTimeEnd() {
        return playTimeEnd;
    }

    public void setPlayTimeEnd(Date playTimeEnd) {
        this.playTimeEnd = playTimeEnd;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getPageLayout() {
        return pageLayout;
    }

    public void setPageLayout(String pageLayout) {
        this.pageLayout = pageLayout;
    }

    public String getPosition() {
        return position;
    }

    public void setPosition(String position) {
        this.position = position;
    }

    public Integer getExposureNumber() {
        return exposureNumber;
    }

    public void setExposureNumber(Integer exposureNumber) {
        this.exposureNumber = exposureNumber;
    }

    public String getVenue() {
        return venue;
    }

    public void setVenue(String venue) {
        this.venue = venue;
    }

    public String getTheaterName() {
        return theaterName;
    }

    public void setTheaterName(String theaterName) {
        this.theaterName = theaterName;
    }

    public Integer getMediaNumber() {
        return mediaNumber;
    }

    public void setMediaNumber(Integer mediaNumber) {
        this.mediaNumber = mediaNumber;
    }

    public String getBanner() {
        return banner;
    }

    public void setBanner(String banner) {
        this.banner = banner;
    }

    public Long getBrightTimeStart() {
        return brightTimeStart;
    }

    public void setBrightTimeStart(Long brightTimeStart) {
        this.brightTimeStart = brightTimeStart;
    }

    public Long getBrightTimeEnd() {
        return brightTimeEnd;
    }

    public void setBrightTimeEnd(Long brightTimeEnd) {
        this.brightTimeEnd = brightTimeEnd;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getMunicipality() {
        return municipality;
    }

    public void setMunicipality(String municipality) {
        this.municipality = municipality;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getPlot() {
        return plot;
    }

    public void setPlot(String plot) {
        this.plot = plot;
    }

    public String getRoadName() {
        return roadName;
    }

    public void setRoadName(String roadName) {
        this.roadName = roadName;
    }

    public String getBuilding() {
        return building;
    }

    public void setBuilding(String building) {
        this.building = building;
    }

    public String getCompetitionInformation() {
        return competitionInformation;
    }

    public void setCompetitionInformation(String competitionInformation) {
        this.competitionInformation = competitionInformation;
    }

    public Timestamp getReleaseTimeStart() {
        return releaseTimeStart;
    }

    public void setReleaseTimeStart(Timestamp releaseTimeStart) {
        this.releaseTimeStart = releaseTimeStart;
    }

    public Timestamp getReleaseTimeEnd() {
        return releaseTimeEnd;
    }

    public void setReleaseTimeEnd(Timestamp releaseTimeEnd) {
        this.releaseTimeEnd = releaseTimeEnd;
    }

    public BigDecimal getItemMoney() {
        return itemMoney;
    }

    public void setItemMoney(BigDecimal itemMoney) {
        this.itemMoney = itemMoney;
    }

    public BigDecimal getAnnualAmountOfMedia() {
        return annualAmountOfMedia;
    }

    public void setAnnualAmountOfMedia(BigDecimal annualAmountOfMedia) {
        this.annualAmountOfMedia = annualAmountOfMedia;
    }

    public Integer getFrequency() {
        return frequency;
    }

    public void setFrequency(Integer frequency) {
        this.frequency = frequency;
    }

    public String getSpecificDeliveryProject() {
        return specificDeliveryProject;
    }

    public void setSpecificDeliveryProject(String specificDeliveryProject) {
        this.specificDeliveryProject = specificDeliveryProject;
    }

    public String getLine() {
        return line;
    }

    public void setLine(String line) {
        this.line = line;
    }

    public String getMaterial() {
        return material;
    }

    public void setMaterial(String material) {
        this.material = material;
    }

    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }

    public String getCarBodySize() {
        return carBodySize;
    }

    public void setCarBodySize(String carBodySize) {
        this.carBodySize = carBodySize;
    }

    public String getStartingPoint() {
        return startingPoint;
    }

    public void setStartingPoint(String startingPoint) {
        this.startingPoint = startingPoint;
    }

    public String getDestination() {
        return destination;
    }

    public void setDestination(String destination) {
        this.destination = destination;
    }

    public String getExpresswayName() {
        return expresswayName;
    }

    public void setExpresswayName(String expresswayName) {
        this.expresswayName = expresswayName;
    }

    public Integer getRotation() {
        return rotation;
    }

    public void setRotation(Integer rotation) {
        this.rotation = rotation;
    }

    public Long getComputerBootTime() {
        return computerBootTime;
    }

    public void setComputerBootTime(Long computerBootTime) {
        this.computerBootTime = computerBootTime;
    }

    public Long getComputerShutdownTime() {
        return computerShutdownTime;
    }

    public void setComputerShutdownTime(Long computerShutdownTime) {
        this.computerShutdownTime = computerShutdownTime;
    }

    public String getNetwortName() {
        return networtName;
    }

    public void setNetwortName(String networtName) {
        this.networtName = networtName;
    }

    public String getNetwortCode() {
        return networtCode;
    }

    public void setNetwortCode(String networtCode) {
        this.networtCode = networtCode;
    }

    public String getAddJobCode() {
        return addJobCode;
    }

    public void setAddJobCode(String addJobCode) {
        this.addJobCode = addJobCode;
    }

    public String getAddJobPeopleCode() {
        return addJobPeopleCode;
    }

    public void setAddJobPeopleCode(String addJobPeopleCode) {
        this.addJobPeopleCode = addJobPeopleCode;
    }

    public Timestamp getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Timestamp createtime) {
        this.createtime = createtime;
    }

    public Timestamp getMtime() {
        return mtime;
    }

    public void setMtime(Timestamp mtime) {
        this.mtime = mtime;
    }

    public String getLatestUpdatePostCode() {
        return latestUpdatePostCode;
    }

    public void setLatestUpdatePostCode(String latestUpdatePostCode) {
        this.latestUpdatePostCode = latestUpdatePostCode;
    }

    public String getLatestUpdatedPosts() {
        return latestUpdatedPosts;
    }

    public void setLatestUpdatedPosts(String latestUpdatedPosts) {
        this.latestUpdatedPosts = latestUpdatedPosts;
    }

    public Boolean getStop() {
        return stop;
    }

    public void setStop(Boolean stop) {
        this.stop = stop;
    }

    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getLatitude() {
        return latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }

    public Set<Photo> getPhotoes() {
        return photoes;
    }

    public void setPhotoes(Set<Photo> photoes) {
        this.photoes = photoes;
    }

    public String getMediaCode() {
        return mediaCode;
    }

    public void setMediaCode(String mediaCode) {
        this.mediaCode = mediaCode;
    }

    public String getMediaCategoriesName() {
        return mediaCategoriesName = mediaCategories.getName();
    }

    public String getCostTypeName() {
        return costTypeName = costType.getName();
    }

    public String getSubdivisionName() {
        return subdivisionName = subdivision.getName();
    }

    public String getActivityStyleName() {
        return activityStyleName= activityStyle.getName();
    }

    public void setMediaCategoriesName(String mediaCategoriesName) {
        this.mediaCategoriesName = mediaCategoriesName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public void setSubdivisionName(String subdivisionName) {
        this.subdivisionName = subdivisionName;
    }

    public void setActivityStyleName(String activityStyleName) {
        this.activityStyleName = activityStyleName;
    }

    public Integer getTubaOrContentNum() {
        return tubaOrContentNum;
    }

    public void setTubaOrContentNum(Integer tubaOrContentNum) {
        this.tubaOrContentNum = tubaOrContentNum;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public List<String> getDevelopFields() {
        return developFields;
    }

    public void setDevelopFields(List<String> developFields) {
        this.developFields = developFields;
    }
}

==> sfa-rpc-0.0.58-sources.jar: com/biz/sfa/vo/resp/media/AllMarketingSearchListRpcRespVo.java <==
package com.biz.sfa.vo.resp.media;

import com.biz.sfa.enums.ActivityStyleEnum;
import com.biz.sfa.enums.CostTypeEnum;
import com.biz.sfa.enums.MediaCategoriesEnum;
import com.biz.sfa.enums.SubdivisionEnum;

import java.io.Serializable;
import java.math.BigDecimal;
import java.sql.Timestamp;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Created by Administrator on 2017/7/17.
 */
public class AllMarketingSearchListRpcRespVo implements Serializable {

    private static final long serialVersionUID = -2910919988277359904L;

    /**
     * 媒体大类
     */
    private MediaCategoriesEnum mediaCategories;

    /**
     * 媒体大类名称
     */
    private String mediaCategoriesName;

    /**
     * 费用类型
     */
    private CostTypeEnum costType;

    /**
     * 费用类型名称
     */
    private String costTypeName;

    /**
     * 小类
     */
    private SubdivisionEnum subdivision;

    /**
     * 小类名称
     */
    private String subdivisionName;

    /**
     * 活动形式
     */
    private ActivityStyleEnum activityStyle;

    /**
     * 活动形式名称
     */
    private String activityStyleName;

    /**
     * 照片(外键关联)
     */
    private Set<Photo> photoes = new HashSet<Photo>();

    /**
     * 媒体库编码
     */
    private String mediaCode;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 播出开始时间(HH:mm:ss)
     */
    private String playTimeStart;

    /**
     * 单位
     */
    private String unit;

    /**
     * 节目/活动/剧目名称
     */
    private String channelName;

    /**
     * 版面
     */
    private String pageLayout;

    /**
     * 位置
     */
    private String position;

    /**
     * 曝光量
     */
    private Integer exposureNumber;

    /**
     * 场馆
     */
    private String venue;

    /**
     * 站点/影院名称
     */
    private String theaterName;

    /**
     * 媒体数量
     */
    private Integer mediaNumber;

    /**
     * 尺寸（广告尺寸）
     */
    private String banner;

    /**
     * 亮化开始时间(HH:mm:ss)
     */
    private String brightTimeStart;

    /**
     * 亮化结束时间(HH:mm:ss)
     */
    private String brightTimeEnd;

    /**
     * （地理位置）省
     */
    private String province;

    /**
     * （地理位置）市
     */
    private String municipality;

    /**
     * （地理位置）县
     */
    private String county;

    /**
     * 地址详情
     */
    private String address;

    /**
     * 小区/道路名称
     */
    private String plot;

    /**
     * 道路名称
     */
    private String roadName;

    /**
     * 楼宇
     */
    private String building;

    /**
     * 竞品信息
     */
    private String competitionInformation;

    /**
     * 发布开始时间(yyyy-HH-dd)
     */
    private Timestamp releaseTimeStart;

    /**
     * 发布结束时间(yyyy-HH-dd)
     */
    private Timestamp releaseTimeEnd;

    /**
     * 项目金额
     */
    private BigDecimal itemMoney;

    /**
     * 年化媒体金额
     */
    private BigDecimal annualAmountOfMedia;

    /**
     * 频次
     */
    private Integer frequency;

    /**
     * 具体投放项目
     */
    private String specificDeliveryProject;

    /**
     * 线路
     */
    private String line;

    /**
     * 材质
     */
    private String material;

    /**
     * 车牌号
     */
    private String carNumber;

    /**
     * 车身尺寸
     */
    private String carBodySize;

    /**
     *始发站
     */
    private String startingPoint;

    /**
     *终点站
     */
    private String destination;

    /**
     * 高速名称
     */
    private String expresswayName;

    /**
     * 形状(横屏or竖屏)（0=横屏或者1=竖屏）
     */
    private Integer rotation;

    /**
     * 开机时间（HH:mm:ss）
     */
    private String computerBootTime;

    /**
     * 关机时间（HH:mm:ss）
     */
    private String computerShutdownTime;

    /**
     *网点名称
     */
    private String networtName;

    /**
     * 网点编码
     */
    private String networtCode;

    /**
     * 新增岗位编码
     */
    private String addJobCode;

    /**
     * 新增岗位人员编码
     */
    private String addJobPeopleCode;

    /**
     * 创建时间（yyyy-MM-dd HH:mm:ss)
     */
    private Timestamp createtime;

    /**
     * 最新修改时间（yyyy-MM-dd HH:mm:ss)
     */
    private Timestamp mtime;

    /**
     * 最新更新岗位编码
     */
    private String latestUpdatePostCode;

    /**
     * 最新更新岗位下人员
     */
    private String latestUpdatedPosts;

    /**
     * 是否停用
     */
    private Boolean stop;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 维度
     */
    private String latitude;

    /**
     * 大号/内容数量
     */
    private Integer tubaOrContentNum;

    /**
     * 备注
     */
    private String remarks;

    /**
     * 拓展字段
     */
    private List<String> developFields;

    public MediaCategoriesEnum getMediaCategories() {
        return mediaCategories;
    }

    public void setMediaCategories(MediaCategoriesEnum mediaCategories) {
        this.mediaCategories = mediaCategories;
    }

    public String getMediaCategoriesName() {
        return mediaCategoriesName;
    }

    public void setMediaCategoriesName(String mediaCategoriesName) {
        this.mediaCategoriesName = mediaCategoriesName;
    }

    public CostTypeEnum getCostType() {
        return costType;
    }

    public void setCostType(CostTypeEnum costType) {
        this.costType = costType;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public SubdivisionEnum getSubdivision() {
        return subdivision;
    }

    public void setSubdivision(SubdivisionEnum subdivision) {
        this.subdivision = subdivision;
    }

    public String getSubdivisionName() {
        return subdivisionName;
    }

    public void setSubdivisionName(String subdivisionName) {
        this.subdivisionName = subdivisionName;
    }

    public ActivityStyleEnum getActivityStyle() {
        return activityStyle;
    }

    public void setActivityStyle(ActivityStyleEnum activityStyle) {
        this.activityStyle = activityStyle;
    }

    public String getActivityStyleName() {
        return activityStyleName;
    }

    public void setActivityStyleName(String activityStyleName) {
        this.activityStyleName = activityStyleName;
    }

    public Set<Photo> getPhotoes() {
        return photoes;
    }

    public void setPhotoes(Set<Photo> photoes) {
        this.photoes = photoes;
    }

    public String getMediaCode() {
        return mediaCode;
    }

    public void setMediaCode(String mediaCode) {
        this.mediaCode = mediaCode;
    }

    public String getMediaName() {
        return mediaName;
    }

    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    public String getPlayTimeStart() {
        return playTimeStart;
    }

    public void setPlayTimeStart(String playTimeStart) {
        this.playTimeStart = playTimeStart;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getPageLayout() {
        return pageLayout;
    }

    public void setPageLayout(String pageLayout) {
        this.pageLayout = pageLayout;
    }

    public String getPosition() {
        return position;
    }

    public void setPosition(String position) {
        this.position = position;
    }

    public Integer getExposureNumber() {
        return exposureNumber;
    }

    public void setExposureNumber(Integer exposureNumber) {
        this.exposureNumber = exposureNumber;
    }

    public String getVenue() {
        return venue;
    }

    public void setVenue(String venue) {
        this.venue = venue;
    }

    public String getTheaterName() {
        return theaterName;
    }

    public void setTheaterName(String theaterName) {
        this.theaterName = theaterName;
    }

    public Integer getMediaNumber() {
        return mediaNumber;
    }

    public void setMediaNumber(Integer mediaNumber) {
        this.mediaNumber = mediaNumber;
    }

    public String getBanner() {
        return banner;
    }

    public void setBanner(String banner) {
        this.banner = banner;
    }

    public String getBrightTimeStart() {
        return brightTimeStart;
    }

    public void setBrightTimeStart(String brightTimeStart) {
        this.brightTimeStart = brightTimeStart;
    }

    public String getBrightTimeEnd() {
        return brightTimeEnd;
    }

    public void setBrightTimeEnd(String brightTimeEnd) {
        this.brightTimeEnd = brightTimeEnd;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getMunicipality() {
        return municipality;
    }

    public void setMunicipality(String municipality) {
        this.municipality = municipality;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getPlot() {
        return plot;
    }

    public void setPlot(String plot) {
        this.plot = plot;
    }

    public String getRoadName() {
        return roadName;
    }

    public void setRoadName(String roadName) {
        this.roadName = roadName;
    }

    public String getBuilding() {
        return building;
    }

    public void setBuilding(String building) {
        this.building = building;
    }

    public String getCompetitionInformation() {
        return competitionInformation;
    }

    public void setCompetitionInformation(String competitionInformation) {
        this.competitionInformation = competitionInformation;
    }

    public Timestamp getReleaseTimeStart() {
        return releaseTimeStart;
    }

    public void setReleaseTimeStart(Timestamp releaseTimeStart) {
        this.releaseTimeStart = releaseTimeStart;
    }

    public Timestamp getReleaseTimeEnd() {
        return releaseTimeEnd;
    }

    public void setReleaseTimeEnd(Timestamp releaseTimeEnd) {
        this.releaseTimeEnd = releaseTimeEnd;
    }

    public BigDecimal getItemMoney() {
        return itemMoney;
    }

    public void setItemMoney(BigDecimal itemMoney) {
        this.itemMoney = itemMoney;
    }

    public BigDecimal getAnnualAmountOfMedia() {
        return annualAmountOfMedia;
    }

    public void setAnnualAmountOfMedia(BigDecimal annualAmountOfMedia) {
        this.annualAmountOfMedia = annualAmountOfMedia;
    }

    public Integer getFrequency() {
        return frequency;
    }

    public void setFrequency(Integer frequency) {
        this.frequency = frequency;
    }

    public String getSpecificDeliveryProject() {
        return specificDeliveryProject;
    }

    public void setSpecificDeliveryProject(String specificDeliveryProject) {
        this.specificDeliveryProject = specificDeliveryProject;
    }

    public String getLine() {
        return line;
    }

    public void setLine(String line) {
        this.line = line;
    }

    public String getMaterial() {
        return material;
    }

    public void setMaterial(String material) {
        this.material = material;
    }

    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }

    public String getCarBodySize() {
        return carBodySize;
    }

    public void setCarBodySize(String carBodySize) {
        this.carBodySize = carBodySize;
    }

    public String getStartingPoint() {
        return startingPoint;
    }

    public void setStartingPoint(String startingPoint) {
        this.startingPoint = startingPoint;
    }

    public String getDestination() {
        return destination;
    }

    public void setDestination(String destination) {
        this.destination = destination;
    }

    public String getExpresswayName() {
        return expresswayName;
    }

    public void setExpresswayName(String expresswayName) {
        this.expresswayName = expresswayName;
    }

    public Integer getRotation() {
        return rotation;
    }

    public void setRotation(Integer rotation) {
        this.rotation = rotation;
    }

    public String getComputerBootTime() {
        return computerBootTime;
    }

    public void setComputerBootTime(String computerBootTime) {
        this.computerBootTime = computerBootTime;
    }

    public String getComputerShutdownTime() {
        return computerShutdownTime;
    }

    public void setComputerShutdownTime(String computerShutdownTime) {
        this.computerShutdownTime = computerShutdownTime;
    }

    public String getNetwortName() {
        return networtName;
    }

    public void setNetwortName(String networtName) {
        this.networtName = networtName;
    }

    public String getNetwortCode() {
        return networtCode;
    }

    public void setNetwortCode(String networtCode) {
        this.networtCode = networtCode;
    }

    public String getAddJobCode() {
        return addJobCode;
    }

    public void setAddJobCode(String addJobCode) {
        this.addJobCode = addJobCode;
    }

    public String getAddJobPeopleCode() {
        return addJobPeopleCode;
    }

    public void setAddJobPeopleCode(String addJobPeopleCode) {
        this.addJobPeopleCode = addJobPeopleCode;
    }

    public Timestamp getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Timestamp createtime) {
        this.createtime = createtime;
    }

    public Timestamp getMtime() {
        return mtime;
    }

    public void setMtime(Timestamp mtime) {
        this.mtime = mtime;
    }

    public String getLatestUpdatePostCode() {
        return latestUpdatePostCode;
    }

    public void setLatestUpdatePostCode(String latestUpdatePostCode) {
        this.latestUpdatePostCode = latestUpdatePostCode;
    }

    public String getLatestUpdatedPosts() {
        return latestUpdatedPosts;
    }

    public void setLatestUpdatedPosts(String latestUpdatedPosts) {
        this.latestUpdatedPosts = latestUpdatedPosts;
    }

    public Boolean getStop() {
        return stop;
    }

    public void setStop(Boolean stop) {
        this.stop = stop;
    }

    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getLatitude() {
        return latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }

    public Integer getTubaOrContentNum() {
        return tubaOrContentNum;
    }

    public void setTubaOrContentNum(Integer tubaOrContentNum) {
        this.tubaOrContentNum = tubaOrContentNum;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public List<String> getDevelopFields() {
        return developFields;
    }

    public void setDevelopFields(List<String> developFields) {
        this.developFields = developFields;
    }
}
